@@ -22,7 +22,7 @@
 #concentric, eccentric-concentric, repetitions of eccentric-concentric
 #currently only used "c" and "ec". no need of ec-rep because c and ec are repetitive
 #"ecS" is like ec but eccentric and concentric phases are separated, used in findCurves, this is good for treeview to know power... on the 2 phases
-eccons=c("c","ec","ec-rep","ecS") 
+eccons=c("c","ec","ecS") 
 
 g = 9.81
 smoothingAll= 0.1
@@ -36,7 +36,7 @@ cols=c(colSpeed,colForce,colPower); lty=rep(1,3)
 #way A. passing options to a file
 getOptionsFromFile <- function(optionsFile) {
 	optionsCon <- file(optionsFile, 'r')
-	options=readLines(optionsCon,n=16)
+	options=readLines(optionsCon,n=17)
 	close(optionsCon)
 	return (options)
 }
@@ -56,7 +56,7 @@ options=getOptionsFromFile(optionsFile);
 print(options)
 
 OutputData2=options[4] #currently used to display status
-OperatingSystem=options[16]
+OperatingSystem=options[17]
 
 write("(1/5) Starting R", OutputData2)
 
@@ -65,6 +65,8 @@ write("(1/5) Starting R", OutputData2)
 findCurves <- function(rawdata, eccon, min_height, draw, title) {
 	a=cumsum(rawdata)
 	b=extrema(a)
+	print("at findCurves")
+	print(b)
 	
 	start=0; end=0; startH=0
 	tempStart=0; tempEnd=0;
@@ -89,7 +91,7 @@ findCurves <- function(rawdata, eccon, min_height, draw, title) {
 			} 
 			i=i+1; j=j+1
 		}
-	} else { #ec, and ec-rep
+	} else { #ec, ecS
 		row=1; i=1; j=2
 		#when saved a row with ec-con, and there's only this curve, extrema doesn't find maxindex
 		if(length(b$maxindex) == 0) {
@@ -100,6 +102,12 @@ findCurves <- function(rawdata, eccon, min_height, draw, title) {
 			end[2]   =length(a)
 			startH[2]=a[start[2]]
 		}
+
+		#if a person starts stand up and goes down, extrema maxindex don't find the initial position
+		#if this person does 3 squats, only 2 will be found
+		#add first value of all the serie (1ms time) to maxindex to help to detect this first curve
+		b$maxindex = rbind(c(1,1),b$maxindex)
+
 		while(j <= length(b$maxindex[,1])) {
 			tempStart = mean(c(b$maxindex[i,1],b$maxindex[i,2]))
 			tempEnd   = mean(c(b$maxindex[j,1],b$maxindex[j,2]))
@@ -133,11 +141,15 @@ findCurves <- function(rawdata, eccon, min_height, draw, title) {
 		}
 	}
 	if(draw) {
-		plot(a/10,type="l",xlim=c(1,length(a)),xlab="",ylab="",axes=T) #/10 mm -> cm
+		plot((1:length(a))/1000			#ms -> s
+		     ,a/10,				#mm -> cm
+		     type="l",
+		     xlim=c(1,length(a))/1000,		#ms -> s
+		     xlab="",ylab="",axes=T) 
 		title(title, cex.main=1, font.main=1)
-		mtext("time (ms) ",side=1,adj=1,line=-1)
+		mtext("time (s) ",side=1,adj=1,line=-1)
 		mtext("height (cm) ",side=2,adj=1,line=-1)
-		abline(v=b$maxindex,lty=3); abline(v=b$minindex,lty=3)
+		abline(v=b$maxindex/1000,lty=3); abline(v=b$minindex/1000,lty=3)	#ms -> s
 	}
 	return(as.data.frame(cbind(start,end,startH)))
 }
@@ -170,11 +182,72 @@ reduceCurveBySpeed <- function(eccon, row, startT, rawdata, smoothing) {
 }
 
 #go here with every single jump
-kinematicsF <- function(a, mass, smoothingOne, g) {
+kinematicsF <- function(a, mass, smoothingOne, g, eccon, analysisOptions) {
+	print("length unique x in spline")
+	print(length(unique(1:length(a))))
+
 	speed <- smooth.spline( 1:length(a), a, spar=smoothingOne)
 	accel <- predict( speed, deriv=1 )
 	#speed comes in mm/ms when derivate to accel its mm/ms^2 to convert it to m/s^2 need to *1000 because it's quadratic
 	accel$y <- accel$y * 1000 
+	errorSearching = FALSE
+
+	eccentric = 0
+
+	#search propulsiveEnds
+	if(analysisOptions == "p") {
+		if(eccon=="c") {
+			concentric=1:length(a)
+		} else {	#"ec", "ecS"
+			b=extrema(speed$y)
+			print(b)
+			#In all the extrema minindex values, search which range (row) has the min values,
+			#and in this range search last value
+			print("searchMinSpeedEnd")
+			searchMinSpeedEnd = max(which(speed$y == min(speed$y)))
+			print(searchMinSpeedEnd)
+			#In all the extrema maxindex values, search which range (row) has the max values,
+			#and in this range search first value
+			print("searchMaxSpeedIni")
+			searchMaxSpeedIni = min(which(speed$y == max(speed$y)))
+			print(searchMaxSpeedIni)
+			#find the cross between both
+			print("b-Cross")
+			print(b$cross[,1])
+			print("search min cross: crossMinRow")
+			crossMinRow=which(b$cross[,1] > searchMinSpeedEnd & b$cross[,1] < searchMaxSpeedIni)
+			
+			print("AT KINEMATICSF")
+			print(crossMinRow)
+
+			if (length(crossMinRow) > 0) {
+				print(crossMinRow)
+
+				isometricUse = TRUE
+				if(isometricUse) {
+					eccentric=1:min(b$cross[crossMinRow,1])
+					concentric=max(b$cross[crossMinRow,2]):length(a)
+				} else {
+					eccentric=1:mean(b$cross[crossMinRow,1])
+					concentric=mean(b$cross[crossMinRow,2]):length(a)
+				}
+			} else {
+				propulsiveEnds = length(a)
+				errorSearching = TRUE
+			}
+		}
+
+		if(! errorSearching) {
+			#propulsive phase ends when accel is -9.8
+			if(length(which(accel$y[concentric]<=-g)) > 0 & analysisOptions == "p") {
+				propulsiveEnds = max(eccentric) + min(which(accel$y[concentric]<=-g))
+			} else {
+				propulsiveEnds = max(concentric)
+			}
+		}
+	}
+	#end of search propulsiveEnds
+
 
 #	force <- mass*accel$y
 #	if(isJump)
@@ -182,37 +255,50 @@ kinematicsF <- function(a, mass, smoothingOne, g) {
 
 	power <- force*speed$y
 
-	return(list(speedy=speed$y, accely=accel$y, force=force, power=power, mass=mass))
+	if(analysisOptions == "p")
+		return(list(speedy=speed$y[1:propulsiveEnds], accely=accel$y[1:propulsiveEnds], 
+			    force=force[1:propulsiveEnds], power=power[1:propulsiveEnds], mass=mass))
+	else
+		return(list(speedy=speed$y, accely=accel$y, force=force, power=power, mass=mass))
 }
 
-powerBars <- function(kinematics) {
-	meanSpeed <- mean(abs(kinematics$speedy))
+powerBars <- function(eccon, kinematics) {
+	meanSpeed <- mean(kinematics$speedy)
+	#max speed and max speed time can be at eccentric or concentric
 	maxSpeed <- max(abs(kinematics$speedy))
-	meanPower <- mean(abs(kinematics$power))
+	maxSpeedT <- min(which(abs(kinematics$speedy) == maxSpeed))
+
+	if(eccon == "c")
+		meanPower <- mean(kinematics$power)
+	else
+		meanPower <- mean(abs(kinematics$power))
+
 	peakPower <- max(abs(kinematics$power))
 	peakPowerT <- min(which(abs(kinematics$power) == peakPower))
 	pp_ppt <- peakPower / (peakPowerT/1000)	# ms->s
-	meanForce <- mean(abs(kinematics$force))
+	meanForce <- mean(kinematics$force)
 	maxForce <- max(abs(kinematics$force))
 
 	#here paf is generated
 	#mass is not used by powerBars, but used by Kg/W (loadVSPower)
 	#meanForce and maxForce are not used by powerBars, but used by F/S (forceVSSpeed)
-	return(data.frame(meanSpeed, maxSpeed, meanPower,peakPower,peakPowerT,pp_ppt,
+	return(data.frame(meanSpeed, maxSpeed, maxSpeedT, meanPower,peakPower,peakPowerT,pp_ppt,
 			  kinematics$mass,meanForce,maxForce))
 }
 
-kinematicRanges <- function(singleFile,rawdata,curves,mass,smoothingOne,g) {
+kinematicRanges <- function(singleFile,rawdata,curves,mass,smoothingOne,g,eccon,analysisOptions) {
 	n=length(curves[,1])
 	maxSpeedy=0;maxForce=0;maxPower=0
+	myEccon = eccon
 	for(i in 1:n) { 
 		myMass = mass
 		mySmoothingOne = smoothingOne
 		if(! singleFile) {
 			myMass = curves[i,5]
 			mySmoothingOne = curves[i,6]
+			myEccon = curves[i,8]
 		}
-		kn=kinematicsF(rawdata[curves[i,1]:curves[i,2]],myMass,mySmoothingOne,g)
+		kn=kinematicsF(rawdata[curves[i,1]:curves[i,2]],myMass,mySmoothingOne,g,myEccon,analysisOptions)
 		if(max(abs(kn$speedy)) > maxSpeedy)
 			maxSpeedy = max(abs(kn$speedy))
 		if(max(abs(kn$force)) > maxForce)
@@ -237,7 +323,7 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 	meanPowerE = 0
 	meanPowerC = 0
 
-	#eccons ec and ec-rep is the same here (only show one curve)
+	#eccons ec and ecS is the same here (only show one curve)
 	#receive data as cumulative sum
 	lty=c(1,1,1)
 
@@ -308,6 +394,17 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 			plot(startX:length(speed$y),speed$y[startX:length(speed$y)],type="l",
 			     xlim=c(1,length(a)),ylim=ylim,xlab="",ylab="",col="darkgreen",lty=2,lwd=3,axes=F)
 	}
+	
+	#time to arrive to max speed
+	maxSpeedT=min(which(speed$y == max(speed$y)))
+	if(draw & !superpose) {
+		abline(v=maxSpeedT, col=cols[1])
+		points(maxSpeedT, max(speed$y),col=cols[1])
+		mtext(text=paste(round(max(speed$y),2),"m/s",sep=""),side=3,
+		      at=maxSpeedT,cex=.8,col=cols[1], line=.5)
+		mtext(text=maxSpeedT,side=1,at=maxSpeedT,cex=.8,col=cols[1])
+	}
+
 
 	#show extrema values in speed
 	b=extrema(speed$y)
@@ -321,7 +418,7 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 	eccentric=0
 	if(eccon=="c") {
 		concentric=1:length(a)
-	} else {	#"ec", "ec-rep"
+	} else {	#"ec", "ecS"
 		print("EXTREMA")
 		#abline(v=b$maxindex,lty=3,col="yellow");
 		#abline(v=b$minindex,lty=3,col="magenta")
@@ -336,18 +433,35 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 		print("searchMaxSpeedIni")
 		searchMaxSpeedIni = min(which(speed$y == max(speed$y)))
 		#find the cross between both
-		print("searchMinCross")
+		print("search min cross: crossMinRow")
 		crossMinRow=which(b$cross[,1] > searchMinSpeedEnd & b$cross[,1] < searchMaxSpeedIni)
+			
+		print("AT PAINT")
+		print(crossMinRow)
+		#maybe there are some crossMinRow's because speed crosses more than one time
+		#use min and max values of crossMinRow
+		
+		isometricUse = TRUE
+		if(isometricUse) {
+			eccentric=1:min(b$cross[crossMinRow,1])
+			concentric=max(b$cross[crossMinRow,2]):length(a)
+			isometric=c(min(b$cross[crossMinRow,1]), max(b$cross[crossMinRow,2]))
+		} else {
+			eccentric=1:mean(b$cross[crossMinRow,1])
+			concentric=mean(b$cross[crossMinRow,2]):length(a)
+			isometric=c(mean(b$cross[crossMinRow,1]), mean(b$cross[crossMinRow,2]))
+		}
 
-		eccentric=1:b$cross[crossMinRow,1]
-		concentric=b$cross[crossMinRow,2]:length(a)
-		isometric=c(b$cross[crossMinRow,1],b$cross[crossMinRow,2])
 		if(draw) {
 			abline(v=max(eccentric),col=cols[1])
 			abline(v=min(concentric),col=cols[1])
 			#mtext(text=paste(max(eccentric)," ",sep=""),side=1,at=max(eccentric),adj=1,cex=.8,col=cols[1])
 			#mtext(text=paste(" ",min(concentric),sep=""),side=1,at=min(concentric),adj=0,cex=.8,col=cols[1])
-			mtext(text=mean(isometric),side=1,at=mean(isometric),adj=0.5,cex=.8,col=cols[1])
+
+			mtext(text=paste(round(min(isometric),1), " ",sep=""), 
+			      side=1,at=min(isometric),adj=1,cex=.8,col=cols[1])
+			mtext(text=paste(" ", round(max(isometric),1),sep=""), 
+			      side=1,at=max(isometric),adj=0,cex=.8,col=cols[1])
 			mtext(text="eccentric ",side=3,at=max(eccentric),cex=.8,adj=1,col=cols[1],line=.5)
 			mtext(text=" concentric ",side=3,at=min(concentric),cex=.8,adj=0,col=cols[1],line=.5)
 		}
@@ -366,9 +480,9 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 	if(draw) {
 		#propulsive phase ends when accel is -9.8
 		if(length(which(accel$y[concentric]<=-g)) > 0 & AnalysisOptions == "p") {
-			propulsiveEnds = min(which(accel$y[concentric]<=-g))
+			propulsiveEnds = max(eccentric) + min(which(accel$y[concentric]<=-g))
 		} else {
-			propulsiveEnds=max(concentric)
+			propulsiveEnds = max(concentric)
 		}
 
 		ylim=c(-max(abs(range(accel$y))),max(abs(range(accel$y))))	 #put 0 in the middle
@@ -390,17 +504,25 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 		#plot the speed axis
 		if(showAxes) {
 			abline(h=0,lty=3,col="black")
-			if(eccon == "c") 
+			if(eccon == "c") {
 				axis(4, at=c(min(axTicks(4)),0,max(axTicks(4)),meanSpeedC),
 				     labels=c(min(axTicks(4)),0,max(axTicks(4)),
-					      parse(text=paste("paste(bar(x),'c=',",round(meanSpeedC,1),")"))),
+					      round(meanSpeedC,1)),
 				     col=cols[1], lty=lty[1], line=0, lwd=1, padj=-.5)
-			else
+				axis(4, at=meanSpeedC,
+				     labels="Xc",
+				     col=cols[1], lty=lty[1], line=0, lwd=1, padj=-2)
+			}
+			else {
 				axis(4, at=c(min(axTicks(4)),0,max(axTicks(4)),meanSpeedE,meanSpeedC),
 				     labels=c(min(axTicks(4)),0,max(axTicks(4)),
-					      parse(text=paste("paste(bar(x),'e=',",round(meanSpeedE,1),")")),
-					      parse(text=paste("paste(bar(x),'c=',",round(meanSpeedC,1),")"))),
+					      round(meanSpeedE,1),
+					      round(meanSpeedC,1)),
 				     col=cols[1], lty=lty[1], line=0, lwd=1, padj=-.5)
+				axis(4, at=c(meanSpeedE,meanSpeedC),
+				     labels=c("Xe","Xc"),
+				     col=cols[1], lty=lty[1], line=0, lwd=0, padj=-2)
+			}
 		}
 
 		par(new=T)
@@ -504,26 +626,34 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 		}
 
 		if(showAxes) {
-			if(eccon == "c") 
+			if(eccon == "c") {
 				axis(4, at=c(min(axTicks(4)),0,max(axTicks(4)),meanPowerC),
 				     labels=c(min(axTicks(4)),0,max(axTicks(4)),
-					      parse(text=paste("paste(bar(x),'c=',",round(meanPowerC,1),")"))),
+					      round(meanPowerC,1)),
 				     col=cols[3], lty=lty[1], line=6, lwd=2, padj=-.5)
-			else
-				axis(4, at=c(min(axTicks(4)),0,max(axTicks(4)),meanPowerE, meanPowerC),
+				axis(4, at=meanPowerC,
+				     labels="Xc",
+				     col=cols[3], lty=lty[1], line=6, lwd=2, padj=-2)
+			}
+			else {
+				axis(4, at=c(min(axTicks(4)),0,max(axTicks(4)),meanPowerE,meanPowerC),
 				     labels=c(min(axTicks(4)),0,max(axTicks(4)),
-					      parse(text=paste("paste(bar(x),'e=',",round(meanPowerE,1),")")),
-					      parse(text=paste("paste(bar(x),'c=',",round(meanPowerC,1),")"))),
-				     col=cols[3], lty=lty[1], line=6, lwd=2, padj=-.5)
+					      round(meanPowerE,1),
+					      round(meanPowerC,1)),
+				     col=cols[3], lty=lty[1], line=6, lwd=1, padj=-.5)
+				axis(4, at=c(meanPowerE,meanPowerC),
+				     labels=c("Xe","Xc"),
+				     col=cols[3], lty=lty[1], line=6, lwd=0, padj=-2)
+			}
 		}
 	}
 
 	#time to arrive to peak power
-	peakPowerT=which(power == max(power))
+	peakPowerT=min(which(power == max(power)))
 	if(draw & !superpose) {
 		abline(v=peakPowerT, col=cols[3])
 		points(peakPowerT, max(power),col=cols[3])
-		mtext(text=paste("peak power:",round(max(power),3)),side=3,at=peakPowerT,cex=.8,col=cols[3])
+		mtext(text=paste(round(max(power),1),"W",sep=""),side=3,at=peakPowerT,cex=.8,col=cols[3])
 		mtext(text=peakPowerT,side=1,at=peakPowerT,cex=.8,col=cols[3])
 	}
 
@@ -534,12 +664,12 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 			#http://stackoverflow.com/a/7322792
 			rng=par("usr")
 			lg = legend(0,rng[2], 
-				    legend=c("Distance","Speed","Accel.","Force","Power"), 
+				    legend=c("Distance (mm)","Speed (m/s)","Accel. (m/s²)","Force (N)","Power (W)"), 
 				    lty=c(1,1,1,1,1), lwd=c(2,2,2,2,2), 
 				    col=c("black",cols[1],"magenta",cols[2],cols[3]), 
 				    cex=1, bg="white", ncol=6, bty="n", plot=F)
 			legend(0,rng[4]+1.25*lg$rect$h, 
-			       legend=c("Distance","Speed","Accel.","Force","Power"), 
+			       legend=c("Distance (mm)","Speed (m/s)","Accel. (m/s²)","Force (N)","Power (W)"), 
 			       lty=c(1,1,1,1,1), lwd=c(2,2,2,2,2), 
 			       col=c("black",cols[1],"magenta",cols[2],cols[3]), 
 			       cex=1, bg="white", ncol=6, bty="n", plot=T, xpd=NA)
@@ -555,6 +685,7 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, myEccons, Eccon, hei
 	pafColors=c("tomato1","tomato4",topo.colors(10)[3])
 	myNums = rownames(paf)
 	height = abs(height/10)
+	load = paf[,findPosInPaf("Load","")]
 	
 	if(Eccon=="ecS") {
 		if(singleFile) {
@@ -564,7 +695,21 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, myEccons, Eccon, hei
 		}
 	}
 	
-	powerData=rbind(paf[,3], paf[,4])
+	powerData=rbind(paf[,findPosInPaf("Power","mean")], paf[,findPosInPaf("Power","max")])
+
+	#when eccon != c show always ABS power
+	#peakPower is always ABS
+	if(Eccon == "c") {
+		powerName = "Power"
+		peakPowerName = "Peak Power (ABS)"
+	}
+	else {
+		powerName = "Power (ABS)"
+		peakPowerName = "Peak Power (ABS)"
+	}
+
+	print("powerData")
+	print(powerData)
 
 	#put lowerY on power, but definetively, leave it at 0
 	#lowerY=min(powerData)-100
@@ -574,7 +719,7 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, myEccons, Eccon, hei
 	
 	par(mar=c(2.5, 4, 5, 5))
 	bp <- barplot(powerData,beside=T,col=pafColors[1:2],width=c(1.4,.6),
-			names.arg=paste(myNums,"\n",paf[,7],sep=""),xlim=c(1,n*3+.5),cex.name=0.9,
+			names.arg=paste(myNums,"\n",load,sep=""),xlim=c(1,n*3+.5),cex.name=0.9,
 			xlab="",ylab="Power (W)", 
 			ylim=c(lowerY,max(powerData)), xpd=FALSE) #ylim, xpd = F,  makes barplot starts high (compare between them)
 	title(main=title,line=-2,outer=T)
@@ -582,33 +727,46 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, myEccons, Eccon, hei
 	par(new=T, xpd=T)
 	#on ecS, concentric has high value of time to peak power and eccentric has it very low. Don't draw lines
 	if(Eccon=="ecS")
-		plot(bp[2,],paf[,5],type="p",lwd=2,xlim=c(1,n*3+.5),ylim=c(0,max(paf[,5])),
+		plot(bp[2,],paf[,findPosInPaf("Power","time")],type="p",lwd=2,
+		     xlim=c(1,n*3+.5),ylim=c(0,max(paf[,findPosInPaf("Power","time")])),
 		     axes=F,xlab="",ylab="",col="blue", bg="lightblue",cex=1.5,pch=21)
 	else
-		plot(bp[2,],paf[,5],type="b",lwd=2,xlim=c(1,n*3+.5),ylim=c(0,max(paf[,5])),
+		plot(bp[2,],paf[,findPosInPaf("Power","time")],type="b",lwd=2,
+		     xlim=c(1,n*3+.5),ylim=c(0,max(paf[,findPosInPaf("Power","time")])),
 		     axes=F,xlab="",ylab="",col=pafColors[3])
 	
 	axis(4, col=pafColors[3], line=0,padj=-.5)
 	mtext("Time to peak power (ms)", side=4, line=-1)
-	
-	par(new=T)
-	plot(bp[2,],height,type="b",lwd=2,xlim=c(1,n*3+.5),ylim=c(0,max(height)),axes=F,xlab="",ylab="",col="green")
 
-	#plot legend on top exactly out
-	#http://stackoverflow.com/a/7322792
-	rng=par("usr")
-	lg = legend(rng[1], rng[2],
-		    col=c(pafColors,"green"), lty=c(0,0,1,1), lwd=c(1,1,2,2), pch=c(15,15,NA,NA), 
-		    legend=c("Power","Peak Power", "Time to Peak Power    ", "Range"), ncol=4, bty="n", plot=F)
-	legend(rng[1], rng[4]+1.25*lg$rect$h,
-	       col=c(pafColors,"green"), lty=c(0,0,1,1), lwd=c(1,1,2,2), pch=c(15,15,NA,NA), 
-	       legend=c("Power","Peak Power", "Time to Peak Power    ", "Range"), ncol=4, bty="n", plot=T, xpd=NA)
-	
+	#range	
+	par(new=T)
+	plot(bp[2,],height,type="p",lwd=2,xlim=c(1,n*3+.5),ylim=c(0,max(height)),axes=F,xlab="",ylab="",col="green")
+
 	abline(h=max(height),lty=2, col="green")
 	abline(h=min(height),lty=2, col="green")
 	#text(max(bp[,2]),max(height),max(height),adj=c(0,.5),cex=0.8)
 	axis(4, col="green", line=3, padj=-.5)
 	mtext("Range (cm)", side=4, line=2)
+	
+	for(i in unique(load)) { 
+		#print(paste("mean",i,mean(height[which(load == i)])))
+		segments(
+			 bp[2,min(which(load == i))],mean(height[which(load == i)]),
+			 bp[2,max(which(load == i))],mean(height[which(load == i)]),
+			 lty=1,col="green")
+		text(x=mean(bp[2,which(load == i)]),y=mean(height[which(load == i)]),
+		     labels=round(mean(height[which(load == i)]),1),adj=c(.5,0),cex=.9)
+	}
+	
+	#plot legend on top exactly out
+	#http://stackoverflow.com/a/7322792
+	rng=par("usr")
+	lg = legend(rng[1], rng[2],
+		    col=c(pafColors,"green"), lty=c(0,0,1,1), lwd=c(1,1,2,2), pch=c(15,15,NA,NA), 
+		    legend=c(powerName, peakPowerName, "Time to Peak Power    ", "Range"), ncol=4, bty="n", plot=F)
+	legend(rng[1], rng[4]+1.25*lg$rect$h,
+	       col=c(pafColors,"green"), lty=c(0,0,1,1), lwd=c(1,1,2,2), pch=c(15,15,NA,NA), 
+	       legend=c(powerName, peakPowerName, "Time to Peak Power    ", "Range"), ncol=4, bty="n", plot=T, xpd=NA)
 }
 
 #see paf for more info
@@ -617,53 +775,108 @@ findPosInPaf <- function(var, option) {
 	if(var == "Speed")
 		pos = 1
 	else if(var == "Power")
-		pos = 3
+		pos = 4
 	else if(var == "Load") #or Mass
-		pos = 7
-	else if(var == "Force")
 		pos = 8
+	else if(var == "Force")
+		pos = 9
 	if( ( var == "Speed" || var == "Power" || var == "Force") & option == "max")
 		pos=pos+1
+	if( ( var == "Speed" || var == "Power") & option == "time")
+		pos=pos+2
 	return(pos)
 }
 
 #option: mean or max
-paintCrossVariables <- function (paf, varX, varY, option, isAlone, title) {
+paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, singleFile, Eccon, seriesName) {
 	x = (paf[,findPosInPaf(varX, option)])
 	y = (paf[,findPosInPaf(varY, option)])
 
-	#problem with balls is that two values two close looks bad
-	#suboption="balls"
-	suboption="side"
-	if(suboption == "balls") {
-		cexBalls = 3
-		cexNums = 1
-		adjHor = 0.5
-		nums=rownames(paf)
-	} else if (suboption == "side") {
-		cexBalls = 1.8
-		cexNums = 1
-		adjHor = 0
-		nums=paste("  ", rownames(paf))
-	}
+	print("seriesName")
+	print(seriesName)
+
+	colBalls = NULL
+	bgBalls = NULL
+
+	#if only one series
+	if(length(unique(seriesName)) == 1) {
+		myNums = rownames(paf)
+		if(Eccon=="ecS") {
+			if(singleFile) {
+				myEc=c("c","e")
+				myNums = as.numeric(rownames(paf))
+				myNums = paste(trunc((myNums+1)/2),myEc[((myNums%%2)+1)],sep="")
+			}
+		}
+
+		#problem with balls is that two values two close looks bad
+		#suboption="balls"
+		suboption="side"
+		if(suboption == "balls") {
+			cexBalls = 3
+			cexNums = 1
+			adjHor = 0.5
+			nums=myNums
+		} else if (suboption == "side") {
+			cexBalls = 1.8
+			cexNums = 1
+			adjHor = 0
+			nums=paste("  ", myNums)
+		}
+
+		colBalls="blue"
+		bgBalls="lightBlue"
+		if(isAlone == "RIGHT") {
+			colBalls="red"
+			bgBalls="pink"
+		}
+		plot(x,y, xlab=varX, ylab="", pch=21,col=colBalls,bg=bgBalls,cex=cexBalls,axes=F)
 	
-	colBalls="blue"
-	bgBalls="lightBlue"
-	if(isAlone == "RIGHT") {
-		colBalls="red"
-		bgBalls="pink"
-	}
+		#x vector should contain at least 4 different values
+		if(length(unique(x)) >= 4)
+			lines(smooth.spline(x,y,df=4),col=colBalls,lwd=2)
+		
+		title(title, cex.main=1, font.main=2)
+		text(x,y,nums,adj=c(adjHor,.5),cex=cexNums)
 
-	plot(x,y, xlab=varX, ylab="", pch=21,col=colBalls,bg=bgBalls,cex=cexBalls,axes=F)
-	title(title, cex.main=1, font.main=2)
-	text(x,y,nums,adj=c(adjHor,.5),cex=cexNums)
+	} else { #more than one series
+		#colBalls = "black"
+		uniqueColors=topo.colors(length(unique(seriesName)))
 
-	#lines(smooth.spline(x,y,spar=.5),col="darkblue")
+		#in x axis move a little every series to right in order to compare
+		seqX = seq(0,length(unique(seriesName))-1,by=1)-(length(unique(seriesName))-1)/2
+
+		for(i in 1:length(seriesName)) {
+			thisSerie = which(seriesName == unique(seriesName)[i])
+			colBalls[thisSerie] = uniqueColors[i]
+			#in x axis move a little every series to right in order to compare
+			x[thisSerie] = x[thisSerie] + seqX[i]
+		}
+		
+		plot(x,y, xlab=varX, ylab="", pch=19, col=colBalls, cex=1.8, axes=F)
+		
+		for(i in 1:length(seriesName)) {
+			thisSerie = which(seriesName == unique(seriesName)[i])
+			if(length(unique(x[thisSerie])) >= 4)
+				lines(smooth.spline(x[thisSerie],y[thisSerie],df=4),col=uniqueColors[i],lwd=2)
+		}
 	
-	#x vector should contain at least 4 different values
-	if(length(unique(x)) >= 4)
-		lines(smooth.spline(x,y,df=4),col=colBalls)
-
+		#difficult to create a title in series graphs
+		title(paste(varX,"/",varY), cex.main=1, font.main=2)
+			
+		#plot legend on top exactly out
+		#http://stackoverflow.com/a/7322792
+		rng=par("usr")
+		lg = legend(rng[1],rng[2], 
+			    legend=unique(seriesName), lty=1, lwd=2, col=uniqueColors, 
+			    cex=1, bg="white", ncol=length(unique(seriesName)), bty="n",
+			    plot=F)
+		legend(rng[1],rng[4]+1.25*lg$rect$h, 
+		       legend=unique(seriesName), lty=1, lwd=2, col=uniqueColors, 
+		       cex=1, bg="white", ncol=6, bty="n",
+		       plot=T, xpd=NA)
+	}
+		
 	if(isAlone == "ALONE") {
 		axis(1)
 		axis(2)
@@ -678,11 +891,12 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title) {
 		axis(4,col=colBalls)
 		mtext(varY, side=4, line=3, col=colBalls)
 	}
+
 }
 
 #propulsive!!!!
 paint1RMBadillo2010 <- function (paf, title) {
-	curvesLoad = (paf[,7]) 					#mass: X
+	curvesLoad = (paf[,findPosInPaf("Load","")]) 		#mass: X
 	curvesSpeed = (paf[,findPosInPaf("Speed", "mean")])	#mean speed Y
 
 	par(mar=c(5,6,3,4))
@@ -700,16 +914,24 @@ paint1RMBadillo2010 <- function (paf, title) {
 	loadPercentCalc=8.4326*curvesSpeed^2 - 73.501*curvesSpeed + 112.33
 	loadCalc= 100 * curvesLoad / loadPercentCalc
 
-	par(mar=c(5,5,3,4))
+	#for calculations take only the curves slower or == than 1.33
+	curvesSpeedInIntervalPos = which(curvesSpeed <= max(msp))
+
+	if(length(curvesSpeedInIntervalPos) == 0) {
+		plot(x=0,xlab="",ylab="",axes=F,type="n")
+		return()
+	}
+
+	par(mar=c(6,5,3,4))
 
 	plot(curvesLoad,curvesSpeed, type="p",
 	     main=paste(title, "1RM prediction"),
-	     sub="Adapted from Gonzalez-Badillo, Sanchez-Medina (2010)",
-	     xlim=c(min(curvesLoad),max(loadCalc)),
+	     sub="\nConcentric mean speed on bench press 1RM is 0.185m/s. Estimated percentual load = 8.4326 * speed ^2 - 73.501 * speed + 112.33\nAdapted from Gonzalez-Badillo, Sanchez-Medina (2010)",
+	     xlim=c(min(curvesLoad),max(loadCalc[curvesSpeedInIntervalPos])),
 	     ylim=c(miny,maxy), xlab="", ylab="",axes=T)
 
 	mtext(side=1,line=2,"Kg")
-	mtext(side=2,line=3,"Mean speed in propulsive phase (m/s)")
+	mtext(side=2,line=3,"Mean speed in concentric propulsive phase (m/s)")
 	mtext(side=4,line=2,"1RM (%)")
 
 	abline(h=msp, lty=2, col="gray")
@@ -786,8 +1008,9 @@ doProcess <- function(options) {
 	Jump=options[12]
 	Width=as.numeric(options[13])
 	Height=as.numeric(options[14])
-	Title=options[15]
-	OperatingSystem=options[16]
+	DecimalSeparator=options[15]
+	Title=options[16]
+	OperatingSystem=options[17]
 
 	print(File)
 	print(OutputGraph)
@@ -814,6 +1037,7 @@ doProcess <- function(options) {
 		par(mar=c(2,2.5,2,1))
 	}
 
+	#when a csv is used (it links to lot of files) then singleFile = false
 	singleFile = TRUE
 	if(nchar(File) >= 40) {
 		#file="/tmp...../chronojump-encoder-graph-input-multi.csv"
@@ -839,6 +1063,7 @@ doProcess <- function(options) {
 		start = NULL; end = NULL; startH = NULL
 		status = NULL; id = NULL; exerciseName = NULL; mass = NULL; smooth = NULL
 		dateTime = NULL; myEccon = NULL; curvesHeight = NULL
+		seriesName = NULL
 
 		newLines=0;
 		countLines=1; #useful to know the correct ids of active curves
@@ -850,8 +1075,13 @@ doProcess <- function(options) {
 				countLines=countLines+1;
 				next;
 			}
-
+			
 			dataTempFile=scan(file=as.vector(inputMultiData$fullURL[i]),sep=",")
+
+			#if curves file ends with comma. Last character will be an NA. remove it
+			#this removes all NAs on a curve
+			dataTempFile  = dataTempFile[!is.na(dataTempFile)]
+
 			dataTempPhase=dataTempFile
 			processTimes = 1
 			changePos = 0
@@ -901,6 +1131,8 @@ doProcess <- function(options) {
 						myEccon[(i+newLines)] = "ec"
 					countLines = countLines + 1
 				}
+				
+				seriesName[(i+newLines)] = as.vector(inputMultiData$seriesName[i])
 
 				count = count + length(dataTempPhase)
 			}
@@ -917,16 +1149,20 @@ doProcess <- function(options) {
 		#solution:
 		if(length(id)==1) {
 			curves = data.frame(start,end,startH,exerciseName,mass,smooth,
-					    dateTime,myEccon,stringsAsFactors=F,row.names=id)
+					    dateTime,myEccon,seriesName,stringsAsFactors=F,row.names=id)
 		} else {
 			curves = data.frame(id,start,end,startH,exerciseName,mass,smooth,
-					    dateTime,myEccon,stringsAsFactors=F,row.names=1)
+					    dateTime,myEccon,seriesName,stringsAsFactors=F,row.names=1)
 		}
 
 		n=length(curves[,1])
 		quitIfNoData(n, curves, OutputData1)
 	} else {
 		rawdata=scan(file=File,sep=",")
+			
+		#if data file ends with comma. Last character will be an NA. remove it
+		#this removes all NAs
+		rawdata  = rawdata[!is.na(rawdata)]
 
 		if(length(rawdata)==0) {
 			plot(0,0,type="n",axes=F,xlab="",ylab="")
@@ -961,9 +1197,10 @@ doProcess <- function(options) {
 						adjVert = 1
 					}
 				}
-				text(x=(curves[i,1]+curves[i,2])/2,y=myY,labels=myLabel, adj=c(0.5,adjVert),cex=1,col="blue")
-				arrows(x0=curves[i,1],y0=myY,x1=curves[i,2],y1=myY,
-				       col="blue",code=3,length=0.1)
+				text(x=((curves[i,1]+curves[i,2])/2/1000),	#/1000 ms -> s
+				     y=myY,labels=myLabel, adj=c(0.5,adjVert),cex=1,col="blue")
+				arrows(x0=(curves[i,1]/1000),y0=myY,x1=(curves[i,2]/1000),	#/1000 ms -> s
+				       y1=myY, col="blue",code=3,length=0.1)
 			}
 		}
 	}
@@ -982,7 +1219,7 @@ doProcess <- function(options) {
 				mySmoothingOne = curves[Jump,6]
 				myEccon = curves[Jump,8]
 			}
-			myCurveStr = paste("c=", Jump, ", ", myMass, "Kg", sep="")
+			myCurveStr = paste("curve=", Jump, ", ", myMass, "Kg", sep="")
 			paint(rawdata, myEccon, myStart, myEnd,"undefined","undefined",FALSE,FALSE,
 			      1,curves[Jump,3],mySmoothingOne,myMass,
 			      paste(Title, " ", Analysis, " ", myEccon, " ", myCurveStr,
@@ -1006,7 +1243,7 @@ doProcess <- function(options) {
 		#yrange=c(min(a),max(a))
 		yrange=find.yrange(singleFile, rawdata, curves)
 
-		knRanges=kinematicRanges(singleFile,rawdata,curves,Mass,SmoothingOne,g)
+		knRanges=kinematicRanges(singleFile,rawdata,curves,Mass,SmoothingOne,g,Eccon,AnalysisOptions)
 
 		for(i in 1:n) {
 			myMass = Mass
@@ -1022,7 +1259,7 @@ doProcess <- function(options) {
 			if(i == 1)
 				myTitle = paste(Title)
 			
-			mySubtitle = paste("c=", rownames(curves)[i], ", ", myMass, "Kg", sep="")
+			mySubtitle = paste("curve=", rownames(curves)[i], ", ", myMass, "Kg", sep="")
 
 			paint(rawdata, myEccon, curves[i,1],curves[i,2],yrange,knRanges,FALSE,FALSE,
 			      1,curves[i,3],mySmoothingOne,myMass,myTitle,mySubtitle,
@@ -1048,7 +1285,7 @@ doProcess <- function(options) {
 		#yrange=c(min(a),max(a))
 		yrange=find.yrange(singleFile, rawdata,curves)
 
-		knRanges=kinematicRanges(singleFile,rawdata,curves,Mass,SmoothingOne,g)
+		knRanges=kinematicRanges(singleFile,rawdata,curves,Mass,SmoothingOne,g,Eccon,AnalysisOptions)
 		for(i in 1:n) {
 			#in superpose all jumps end at max height
 			#start can change, some are longer than other
@@ -1075,6 +1312,10 @@ doProcess <- function(options) {
 		#print(knRanges)
 	}
 
+	#since Chronojump 1.3.6, encoder analyze has a treeview that can show the curves
+	#when an analysis is done, curves file has to be written
+	writeCurves = TRUE
+
 	#Analysis in cross variables comes as:
 	#"cross.Speed.Force.mean" 	#2nd is Y, 3d is X. "mean" can also be "max"
 	#there's a double XY plot:
@@ -1082,9 +1323,12 @@ doProcess <- function(options) {
 	analysisCross = unlist(strsplit(Analysis, "\\."))
 	if(
 	   Analysis == "powerBars" || analysisCross[1] == "cross" || 
-	   Analysis == "1RMBadillo2010" || Analysis == "curves") 
+	   Analysis == "1RMBadillo2010" || Analysis == "curves" ||
+	   writeCurves) 
 	{
 		paf = data.frame()
+		discardedCurves = NULL
+		discardingCurves = FALSE
 		for(i in 1:n) { 
 			myMass = Mass
 			mySmoothingOne = SmoothingOne
@@ -1093,12 +1337,34 @@ doProcess <- function(options) {
 				myMass = curves[i,5]
 				mySmoothingOne = curves[i,6]
 				myEccon = curves[i,8]
+
+				#only use concentric data	
+				if(Analysis == "1RMBadillo2010" & myEccon == "e") {
+					discardedCurves = c(i,discardedCurves)
+					discardingCurves = TRUE
+					next;
+				}
+			} else {
+				if(Analysis == "1RMBadillo2010" & Eccon == "ecS" & i%%2 == 1) {
+					discardedCurves = c(i,discardedCurves)
+					discardingCurves = TRUE
+					next;
+				}
 			}
-			paf=rbind(paf,(powerBars(kinematicsF(rawdata[curves[i,1]:curves[i,2]], 
-							     myMass, mySmoothingOne, g))))
+
+			print("i:")
+			print(i)
+			paf=rbind(paf,(powerBars(myEccon,
+						 kinematicsF(rawdata[curves[i,1]:curves[i,2]], 
+							     myMass, mySmoothingOne, g, myEccon, AnalysisOptions))))
 		}
-		#print(paf)
-		rownames(paf)=rownames(curves) #put correct rownames when there are inactive curves
+
+		#on 1RMBadillo discard curves "e", because paf has this curves discarded
+		#and produces error on the cbinds below			
+		if(discardingCurves)
+			curves = curves[-discardedCurves,]
+
+		rownames(paf)=rownames(curves)
 		print("----------------------------")
 		print(paf)
 
@@ -1113,26 +1379,56 @@ doProcess <- function(options) {
 							rawdata.cumsum[curves[,2]]-curves[,3], n) #height
 		}
 		else if(analysisCross[1] == "cross") {
+			mySeries = "1"
+			if(! singleFile)
+				mySeries = curves[,9]
+
 			if(analysisCross[2] == "Speed,Power") {
 				par(mar=c(5,4,4,5))
 				analysisCrossVertVars = unlist(strsplit(analysisCross[2], "\\,"))
 				paintCrossVariables(paf, analysisCross[3], analysisCrossVertVars[1], 
-						    analysisCross[4], "LEFT", Title)
+						    analysisCross[4], "LEFT", Title,
+						    singleFile,Eccon,mySeries)
 				par(new=T)
 				paintCrossVariables(paf, analysisCross[3], analysisCrossVertVars[2], 
-						    analysisCross[4], "RIGHT", "")
+						    analysisCross[4], "RIGHT", "",
+						    singleFile,Eccon,mySeries)
 			} else
 				paintCrossVariables(paf, analysisCross[3], analysisCross[2], 
-						    analysisCross[4], "ALONE", Title)
+						    analysisCross[4], "ALONE", Title,
+						    singleFile,Eccon,mySeries)
 		}
 		else if(Analysis == "1RMBadillo2010") {
 			paint1RMBadillo2010(paf, Title)
 		}
-		else if(Analysis == "curves") {
-			paf=cbind(curves[,1],curves[,2]-curves[,1],rawdata.cumsum[curves[,2]]-curves[,3],paf)
-			colnames(paf)=c("start","width","height","meanSpeed","maxSpeed",
-					"meanPower","peakPower","peakPowerT","pp_ppt")
+		
+		if(Analysis == "curves" || writeCurves) {
+			if(singleFile)
+				paf=cbind(
+					  "1",			#seriesName
+					  "exerciseName",
+					  Mass,
+					  curves[,1],
+					  curves[,2]-curves[,1],rawdata.cumsum[curves[,2]]-curves[,3],paf)
+			else {
+				if(discardingCurves)
+					curvesHeight = curvesHeight[-discardedCurves]
+
+				paf=cbind(
+					  curves[,9],		#seriesName
+					  curves[,4],		#exerciseName
+					  curves[,5],		#mass
+					  curves[,1],		
+					  curves[,2]-curves[,1],curvesHeight,paf)
+			}
+
+			colnames(paf)=c("series","exercise","mass",
+					"start","width","height",
+					"meanSpeed","maxSpeed","maxSpeedT",
+					"meanPower","peakPower","peakPowerT",
+					"pp_ppt")
 			write.csv(paf, OutputData1, quote=FALSE)
+			print("curves written")
 		}
 	}
 	if(Analysis=="exportCSV") {
@@ -1148,48 +1444,54 @@ doProcess <- function(options) {
 		}
 
 		curveCols = 6	#change this value if there are more colums
-		names=c("Dist.", "Dist. +", "Speed", "Accel.", "Force", "Power")
+		names=c("DIST.", "DIST. +", "SPEED", "ACCEL.", "FORCE", "POWER")
 		nums=1:curvesNum
 		nums=rep(nums,each=curveCols)		
 		namesNums=paste(names, nums)
+		units=c("\n(mm)", "\n(mm)", "\n(m/s)", "\n(m/s^2)", "\n(N)", "\n(W)")
+		namesNums=paste(namesNums, units)
 
 		for(i in 1:curvesNum) { 
-			kn = kinematicsF (rawdata[curves[i,1]:curves[i,2]], Mass, SmoothingOne, g)
+			kn = kinematicsF (rawdata[curves[i,1]:curves[i,2]], Mass, SmoothingOne, g, Eccon, AnalysisOptions)
 
 			#fill with NAs in order to have the same length
 			col1 = rawdata[curves[i,1]:curves[i,2]]
 			col2 = rawdata.cumsum[curves[i,1]:curves[i,2]]
 
-			#add mean and max
+			#add mean, max, and time to max
 			col1=append(col1,
-				    c(NA,NA,NA,namesNums[((i-1)*curveCols)+1]),
+				    c(NA,NA,NA,NA),
 				    after=0)
 			col2=append(col2,
-				    c(NA,"mean (ABS):","max:",namesNums[((i-1)*curveCols)+2]),
+				    c(NA,NA,NA,range(col2)[2]-range(col2)[1]),
 				    after=0)
 			kn$speedy=append(kn$speedy,
 					 c(
-					   namesNums[((i-1)*curveCols)+3],
-					   mean(abs(kn$speedy)),max(kn$speedy),
-					   namesNums[((i-1)*curveCols)+3]),
+					   mean(abs(kn$speedy)),
+					   max(kn$speedy),
+					   (min(which(kn$speedy == max(kn$speedy)))/1000),
+					   NA),
 					 after=0)
 			kn$accely=append(kn$accely,
 					 c(
-					   namesNums[((i-1)*curveCols)+4],
-					   mean(abs(kn$accely)),max(kn$accely),
-					   namesNums[((i-1)*curveCols)+4]),
+					   mean(abs(kn$accely)),
+					   max(kn$accely),
+					   NA,
+					   NA),
 					 after=0)
 			kn$force=append(kn$force,
 					c(
-					  namesNums[((i-1)*curveCols)+5],
-					  mean(abs(kn$force)),max(kn$force),
-					  namesNums[((i-1)*curveCols)+5]),
+					  mean(abs(kn$force)),
+					  max(kn$force),
+					  NA,
+					  NA),
 					after=0)
 			kn$power=append(kn$power,
 					c(
-					  namesNums[((i-1)*curveCols)+6],
-					  mean(abs(kn$power)),max(kn$power),
-					  namesNums[((i-1)*curveCols)+6]),
+					  mean(abs(kn$power)),
+					  max(kn$power),
+					  (min(which(kn$power == max(kn$power)))/1000),
+					  NA),
 					after=0)
 
 			extraRows=4
@@ -1208,16 +1510,22 @@ doProcess <- function(options) {
 						    kn$speedy, kn$accely, kn$force, kn$power))
 		}
 
+		rownames(df) = c("MEAN (ABS)", "MAX", "TIME TO MAX", "RANGE", 1:maxLength)
+		colnames(df) = namesNums
+
 		#TODO: time
 		#TODO: tenir en compte el startH
 
-		Title=gsub('_',' ',Title)
-		print(Title)
-		titleColumns=unlist(strsplit(Title,'-'))
-		colnames(df)=c(titleColumns[1]," ", titleColumns[2],titleColumns[3],rep(" ",(curvesNum*curveCols-4)))
+		#Title=gsub('_',' ',Title)
+		#print(Title)
+		#titleColumns=unlist(strsplit(Title,'-'))
+		#colnames(df)=c(titleColumns[1]," ", titleColumns[2],titleColumns[3],rep(" ",(curvesNum*curveCols-4)))
+
+		if(DecimalSeparator == "COMMA")
+			write.csv2(df, file=File, row.names=T, na="")
+		else
+			write.csv(df, file=File, row.names=T, na="")
 
-		write.csv2(df, file=File, row.names=F, na="")
-		#write.csv2(df, file=File, quotes=F)
 		print("Export done.")
 	}
 	if(Analysis != "exportCSV")
