@@ -49,6 +49,7 @@ public class EncoderParams
 	private int peakPowerHigherCondition;
 	private int peakPowerLowerCondition;
 	private string mainVariable;
+	private string decimalSeparator;	//used in export data from R to csv
 
 	public EncoderParams()
 	{
@@ -98,7 +99,8 @@ public class EncoderParams
 	
 	//to graph.R	
 	public EncoderParams(int minHeight, int exercisePercentBodyWeight, string mass, string eccon, 
-			string analysis, string analysisOptions, string smooth, int curve, int width, int height)
+			string analysis, string analysisOptions, string smooth, int curve, int width, int height,
+			string decimalSeparator)
 	{
 		this.minHeight = minHeight;
 		this.exercisePercentBodyWeight = exercisePercentBodyWeight;
@@ -110,12 +112,14 @@ public class EncoderParams
 		this.curve = curve;
 		this.width = width;
 		this.height = height;
+		this.decimalSeparator = decimalSeparator;
 	}
 	
 	public string ToString2 (string sep) 
 	{
-		return minHeight + sep + exercisePercentBodyWeight + sep + mass + sep + eccon + sep + 
-			analysis + sep + analysisOptions + sep + smooth + sep + curve + sep + width + sep + height;
+		return minHeight + sep + exercisePercentBodyWeight + sep + mass + sep + eccon + 
+			sep + analysis + sep + analysisOptions + sep + smooth + sep + curve + 
+			sep + width + sep + height + sep + decimalSeparator;
 	}
 	
 	public string Analysis {
@@ -159,8 +163,12 @@ public class EncoderCurve
 	public EncoderCurve () {
 	}
 
-	public EncoderCurve (string n, string start, string duration, string height, string meanSpeed, string maxSpeed, 
-			string meanPower, string peakPower, string peakPowerT, string PP_PPT)
+	//used on TreeView capture
+	public EncoderCurve (string n, 
+			string start, string duration, string height, 
+			string meanSpeed, string maxSpeed, string maxSpeedT,
+			string meanPower, string peakPower, string peakPowerT, 
+			string PP_PPT)
 	{
 		this.N = n;
 		this.Start = start;
@@ -168,6 +176,30 @@ public class EncoderCurve
 		this.Height = height;
 		this.MeanSpeed = meanSpeed;
 		this.MaxSpeed = maxSpeed;
+		this.MaxSpeedT = maxSpeedT;
+		this.MeanPower = meanPower;
+		this.PeakPower = peakPower;
+		this.PeakPowerT = peakPowerT;
+		this.PP_PPT = PP_PPT;	//PeakPower / PeakPowerTime
+	}
+
+	//used on TreeView analyze
+	public EncoderCurve (string n, string series, string exercise, double extraWeight,
+			string start, string duration, string height,
+			string meanSpeed, string maxSpeed, string maxSpeedT,
+			string meanPower, string peakPower, string peakPowerT, 
+			string PP_PPT)
+	{
+		this.N = n;
+		this.Series = series;
+		this.Exercise = exercise;
+		this.ExtraWeight = extraWeight;
+		this.Start = start;
+		this.Duration = duration;
+		this.Height = height;
+		this.MeanSpeed = meanSpeed;
+		this.MaxSpeed = maxSpeed;
+		this.MaxSpeedT = maxSpeedT;
 		this.MeanPower = meanPower;
 		this.PeakPower = peakPower;
 		this.PeakPowerT = peakPowerT;
@@ -175,11 +207,15 @@ public class EncoderCurve
 	}
 
 	public string N;
+	public string Series;
+	public string Exercise;
+	public double ExtraWeight;
 	public string Start;
 	public string Duration;
 	public string Height;
 	public string MeanSpeed;
 	public string MaxSpeed;
+	public string MaxSpeedT;
 	public string MeanPower;
 	public string PeakPower;
 	public string PeakPowerT;
@@ -283,6 +319,35 @@ public class EncoderSQL
 
 }
 
+public class EncoderPersonCurvesInDB
+{
+	public int personID;
+	public int sessionID;
+	public string sessionName;
+	public string sessionDate;
+	public int countActive;
+	public int countAll;
+	
+	public EncoderPersonCurvesInDB() {
+	}
+	public EncoderPersonCurvesInDB(int personID, int sessionID, string sessionName, string sessionDate,
+			int countActive, int countAll) {
+		this.personID =		personID;
+		this.sessionID = 	sessionID;
+		this.sessionName = 	sessionName;
+		this.sessionDate = 	sessionDate;
+		this.countActive = 	countActive;
+		this.countAll =		countAll;
+	}
+
+	public string [] ToStringArray() {
+		string [] s = { "", sessionID.ToString(), sessionName, sessionDate,
+			countActive.ToString(), countAll.ToString()
+		};
+		return s;
+	}
+}
+
 public class EncoderExercise
 {
 	public int uniqueID;
