@@ -61,6 +61,18 @@ public class Util
 		return myStringBuilder.ToString();
 	}
 	
+	//used to send to R and export csv there
+	public static string GetDecimalSeparator() {
+		System.Globalization.NumberFormatInfo localeInfo = new System.Globalization.NumberFormatInfo();
+		localeInfo = System.Globalization.NumberFormatInfo.CurrentInfo;
+
+		if(localeInfo.NumberDecimalSeparator == ".")
+			return("POINT");
+		else if(localeInfo.NumberDecimalSeparator == ",")
+			return("COMMA");
+		else 
+			return("OTHER");
+	}
 	
 	//used for load from the database all numbers with correct decimal separator (locale defined)
 	//used also for the tvString, tcString, and runIntervalTimesString
@@ -327,10 +339,11 @@ public class Util
 		return myStringBuilder.ToString();
 	}
 
-	public static string ChangeSpaceForUnderscore(string myString) 
+	public static string ChangeSpaceAndMinusForUnderscore(string myString) 
 	{
 		StringBuilder myStringBuilder = new StringBuilder(myString);
 		myStringBuilder.Replace(" ", "_");
+		myStringBuilder.Replace("-", "_");
 		return myStringBuilder.ToString();
 	}
 	
@@ -933,12 +946,15 @@ public class Util
 		return fileName;
 	}
 	
-	public static void CopyEncoderDataToTemp(string url, string fileName)
+	public static bool CopyEncoderDataToTemp(string url, string fileName)
 	{
 		string origin = url + Path.DirectorySeparatorChar + fileName;
 		string dest = GetEncoderDataTempFileName();
-		if(File.Exists(origin)) 
+		if(File.Exists(origin)) {
 			File.Copy(origin, dest, true);
+			return true;
+		}
+		return false;
 	}
 	
 	
@@ -1142,7 +1158,6 @@ public class Util
 		string pBin="";
 		pinfo = new ProcessStartInfo();
 
-		string outputFileCheck = "";
 		string operatingSystem = "Linux";
 			
 		pBin="Rscript";
@@ -1206,27 +1221,49 @@ public class Util
 		Log.WriteLine(pinfo.Arguments.ToString());
 		Log.WriteLine("------------- 4 ---");
 		
-		//curves does first graph and then csv curves. 
+		string outputFileCheck = "";
+		string outputFileCheck2 = "";
+		
 		//Wait until this to update encoder gui (if don't wait then treeview will be outdated)
-		if(es.Ep.Analysis == "curves" || es.Ep.Analysis == "exportCSV")
+		//exportCSV is the only one that doesn't have graph. all the rest Analysis have graph and data
+		if(es.Ep.Analysis == "exportCSV")
 			outputFileCheck = es.OutputData1; 
-		else
-			outputFileCheck = es.OutputGraph;
+		else {
+			//outputFileCheck = es.OutputGraph;
+			//
+			//OutputData1 because since Chronojump 1.3.6, 
+			//encoder analyze has a treeview that can show the curves
+			//when a graph analysis is done, curves file has to be written
+			outputFileCheck = es.OutputData1;
+		        //check also the otuput graph
+			outputFileCheck2 = es.OutputGraph; 
+		}
 
 		pinfo.FileName=pBin;
 
 		pinfo.CreateNoWindow = true;
 		pinfo.UseShellExecute = false;
 
-		Console.WriteLine(outputFileCheck);
+		//delete output file check(s)
+		Console.WriteLine("Deleting... " + outputFileCheck);
 		if (File.Exists(outputFileCheck))
 			File.Delete(outputFileCheck);
+
+		if(outputFileCheck2 != "") {
+			Console.WriteLine("Deleting... " + outputFileCheck2);
+			if (File.Exists(outputFileCheck2))
+				File.Delete(outputFileCheck2);
+		}
 	
 		p = new Process();
 		p.StartInfo = pinfo;
 		p.Start();
 		p.WaitForExit();
-		while ( ! ( File.Exists(outputFileCheck) || CancelRScript) );
+
+		if(outputFileCheck2 == "")
+			while ( ! ( File.Exists(outputFileCheck) || CancelRScript) );
+		else
+			while ( ! ( (File.Exists(outputFileCheck) && File.Exists(outputFileCheck2)) || CancelRScript ) );
 	}
 
 	private static string [] encoderFindPos(string contents, int start, int duration) {
@@ -1294,7 +1331,13 @@ public class Util
 		contents = contents.Substring(
 				Convert.ToInt32(startAndDuration[0]), 
 				Convert.ToInt32(startAndDuration[1])-1); //-1 is for not ending file with a comma
-			
+		//don't know why but some curves are stored with a "," as last character
+		//this curves also are in the form: "1, 2, 3, 4," instead of "1,2,3,4"
+		//this produces an NA in reading of curves on graph.R
+		//in the meantime this NA in reading in graph.R has been deleted
+		//dataTempFile  = dataTempFile[!is.na(dataTempFile)]
+		
+
 		string fileCurve = uniqueID.ToString() + "-" + personName + "-" + 
 			(++ curveIDMax).ToString() + "-" + timeStamp + ".txt";
 		string fileCurveFull = GetEncoderSessionDataCurveDir(sessionID) + Path.DirectorySeparatorChar + fileCurve;
@@ -1472,16 +1515,21 @@ public class Util
 		return myArrayList;
 	}
 
-	public static bool FoundInArrayList(ArrayList myArrayList, string str) {
-	 	bool found = false;
-		foreach (string str2 in myArrayList)
+	public static bool FoundInArrayList(ArrayList a, string str) {
+		foreach (string str2 in a)
 			if(str2 == str)
-				found = true;
+				return true;
 
-		return found;
+		return false;
 	}
 
+	public static bool FoundInArrayList(ArrayList a, int i) {
+		foreach (int j in a)
+			if(i == j)
+				return true;
 
+		return false;
+	}
 
 	/*
 	//delete a row of and arraylist of string[] if the string[0] is the value coming from startsWith
